@@ -1,7 +1,7 @@
 # ABSTRACT: The base class for all IO::Storm Bolts.
 
 package IO::Storm::Bolt;
-$IO::Storm::Bolt::VERSION = '0.16';
+$IO::Storm::Bolt::VERSION = '0.17';
 # Imports
 use strict;
 use warnings;
@@ -131,7 +131,7 @@ sub run {
         while (1) {
             $tup = $self->read_tuple();
             $self->_current_tups( [$tup] );
-            if ( $tup->{task} == -1 && $tup->{stream} == '__heartbeat' ) {
+            if ( $tup->{task} == -1 && $tup->{stream} eq '__heartbeat' ) {
                 $self->send_message( { command => 'sync' } );
             }
             else {
@@ -172,7 +172,7 @@ IO::Storm::Bolt - The base class for all IO::Storm Bolts.
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 NAME
 
